# aidkitHW

This repo is for a coding challenge to interface various frameworks eg pytorch (fastai), tensorflow, onnx and inferencing onnx-runtime. The work is best followed on Linux OS with jupyter notebooks.

## Some prerequisites to follow along:

`pip install jupyter notebook`  

In case there's problems installing onnx:  
`sudo apt-get install protobuf-compiler libprotoc-dev`

To use `onnx-tensorflow` for tensorflow-1.x install it using:
```
git clone https://github.com/onnx/onnx-tensorflow.git && cd onnx-tensorflow
git checkout tf-1.x
pip install -e .
```

## The package can be installed via pip:

`pip install aidkitHW`
